@@ -8,12 +8,12 @@
 #include "kratingwidget.h"
 #include "kratingpainter.h"
 
-#include <QPainter>
-#include <QPixmap>
 #include <QIcon>
 #include <QMouseEvent>
+#include <QPainter>
+#include <QPixmap>
 
-class Q_DECL_HIDDEN KRatingWidget::Private
+class KRatingWidgetPrivate
 {
 public:
     int rating = 0;
@@ -24,16 +24,13 @@ public:
 };
 
 KRatingWidget::KRatingWidget(QWidget *parent)
-    : QFrame(parent),
-      d(new Private())
+    : QFrame(parent)
+    , d(new KRatingWidgetPrivate())
 {
     setMouseTracking(true);
 }
 
-KRatingWidget::~KRatingWidget()
-{
-    delete d;
-}
+KRatingWidget::~KRatingWidget() = default;
 
 #if KWIDGETSADDONS_BUILD_DEPRECATED_SINCE(5, 0)
 void KRatingWidget::setPixmap(const QPixmap &pix)
@@ -98,7 +95,11 @@ void KRatingWidget::setLayoutDirection(Qt::LayoutDirection direction)
     update();
 }
 
+#if KWIDGETSADDONS_BUILD_DEPRECATED_SINCE(5, 85)
 unsigned int KRatingWidget::rating() const
+#else
+int KRatingWidget::rating() const
+#endif
 {
     return d->rating;
 }
@@ -125,8 +126,10 @@ void KRatingWidget::setRating(int rating)
     if (rating != d->rating) {
         d->rating = rating;
         d->hoverRating = rating;
-        emit ratingChanged(rating);
-        emit ratingChanged((unsigned int)rating);
+        Q_EMIT ratingChanged(rating);
+#if KWIDGETSADDONS_BUILD_DEPRECATED_SINCE(5, 85)
+        Q_EMIT ratingChanged((unsigned int)rating);
+#endif
         update();
     }
 }
@@ -185,9 +188,7 @@ static inline int adjustedHoverRating(bool halfStep, int hoverRating, int rating
 void KRatingWidget::mousePressEvent(QMouseEvent *e)
 {
     if (e->button() == Qt::LeftButton) {
-        d->hoverRating = adjustedHoverRating(halfStepsEnabled(),
-                                             d->ratingPainter.ratingFromPosition(contentsRect(), e->pos()),
-                                             d->rating);
+        d->hoverRating = adjustedHoverRating(halfStepsEnabled(), d->ratingPainter.ratingFromPosition(contentsRect(), e->pos()), d->rating);
         // avoid set a rating to something less than zero, it may happen if widget is scaled and
         // mouse is clicked outside the star region.
         if (d->hoverRating >= 0) {
@@ -200,9 +201,7 @@ void KRatingWidget::mouseMoveEvent(QMouseEvent *e)
 {
     // when moving the mouse we show the user what the result of clicking will be
     const int prevHoverRating = d->hoverRating;
-    d->hoverRating = adjustedHoverRating(halfStepsEnabled(),
-                                         d->ratingPainter.ratingFromPosition(contentsRect(), e->pos()),
-                                         d->rating);
+    d->hoverRating = adjustedHoverRating(halfStepsEnabled(), d->ratingPainter.ratingFromPosition(contentsRect(), e->pos()), d->rating);
     if (d->hoverRating != prevHoverRating) {
         update();
     }
@@ -234,8 +233,7 @@ QSize KRatingWidget::sizeHint() const
         pixSize = d->ratingPainter.customPixmap().size() / d->ratingPainter.customPixmap().devicePixelRatio();
     }
 
-    return QSize(pixSize.width() * numPix + spacing() * (numPix - 1) + frameWidth() * 2,
-                 pixSize.height() + frameWidth() * 2);
+    return QSize(pixSize.width() * numPix + spacing() * (numPix - 1) + frameWidth() * 2, pixSize.height() + frameWidth() * 2);
 }
 
 void KRatingWidget::resizeEvent(QResizeEvent *e)
